<?php

  include ('funkcje_ksiazka_kz.php');
  // koszyk na zakupy potrzebuje sesji, zostaje więc ona rozpoczęta
  session_start();

  tworz_naglowek_html("Kasa");
  // utworzenie krótkich nazw zmiennych
  $nazwisko = $_POST['nazwisko'];
  $adres = $_POST['adres'];
  $miasto = $_POST['miasto'];
  $kod_poczt = $_POST['kod_poczt'];
  $kraj = $_POST['kraj'];

  // jeżeli wypełniony
  if(($_SESSION['koszyk']) && ($nazwisko) && ($adres) && ($miasto) && ($kod_poczt) && ($kraj)) {
    // możliwe umieszczenie danych w bazie
    if( umiesc_zamowienie($_POST) != false ) {
      //wyświetl koszyk bez możliwości zmian i bez obrazków
      wyswietl_koszyk($_SESSION['koszyk'], false, 0);

      wyswietl_dostawe(oblicz_koszt_dostawy());

      // pobranie szczegółów karty kredytowej
      wyswietl_form_karty($nazwisko);

      wyswietl_przycisk("pokaz_kosz.php", "kontynuacja", "Kontynuacja zakupów");
    } else {
      echo "<p>Nie wypełniono wszystkich pól, proszę spróbować ponownie.</p>";
      wyswietl_przycisk('kasa.php', 'powrot', 'Powrót');
    }
  } else {
    echo "<p>Nie wypełniono wszystkich pól, proszę spróbować ponownie.</p><hr />";
    wyswietl_przycisk('kasa.php', 'powrot', 'Powrót');
  }

  tworz_stopke_html();
?>